@@ -1,5 +1,5 @@
+import ntpath
 import os
-import re
 import shutil
 from copy import deepcopy
 from pathlib import Path
@@ -210,6 +210,8 @@ class AnalysisSTEAM:
                 self.step_postprocess(step, verbose=verbose)
             elif step.type == 'SetUpFolder':
                 self.step_setup_folder(step, verbose=verbose)
+            elif step.type == 'AddAuxiliaryFile':
+                self.add_auxiliary_file(step, verbose=verbose)
             else:
                 raise Exception('Unknown type of analysis step: {}'.format(step.type))
 
@@ -257,7 +259,7 @@ class AnalysisSTEAM:
         if step.model_name not in self.list_models:
             raise Exception('Name of the model to modify ({}) does not correspond to any of the defined models.'.format(step.model_name))
         len_variable_value = len(step.variable_value)
-        len_simulation_numbers  = len(step.simulation_numbers)
+        len_simulation_numbers = len(step.simulation_numbers)
         len_new_model_name = len(step.new_model_name)
         if len_new_model_name > 0 and not len_new_model_name == len_variable_value:
             raise Exception('The length of new_model_name and variable_value must be the same, but they are {} and {} instead.'.format(len_new_model_name, len_variable_value))
@@ -308,8 +310,9 @@ class AnalysisSTEAM:
                 simulation_number = step.simulation_numbers[v]
                 if 'LEDET' in step.software:
                     flag_json = BM.flag_json
+                    flag_yaml = True  # Hard-coded for the moment
                     BM.buildLEDET(case_model=case_model)
-                    self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=simulation_number, flag_json=flag_json)
+                    self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
                 if 'PyBBQ' in step.software:
                     BM.buildPyBBQ()
                     self.setup_sim_PyBBQ(simulation_name=step.simulation_name, sim_number=simulation_number)
@@ -487,6 +490,36 @@ class AnalysisSTEAM:
             else:
                 raise Exception(f'Software {software} not supported for automated folder setup.')
 
+    def add_auxiliary_file(self, step, verbose: bool = False):
+        '''
+        Copy the desired auxiliary file to the output folder
+        '''
+        # Unpack
+        full_path_aux_file = Path(step.full_path_aux_file).resolve()
+        new_file_name      = step.new_file_name
+        output_path = self.output_path
+
+        # If no new name is provided, use the old file name
+        if new_file_name == None:
+            new_file_name = ntpath.basename(full_path_aux_file)
+
+        # Copy auxiliary file to the output folder
+        full_path_output_file = os.path.join(output_path, new_file_name)
+        shutil.copyfile(full_path_aux_file, full_path_output_file)
+        if verbose: print(f'File {full_path_aux_file} was copied to {full_path_output_file}.')
+
+        # Build simulation file
+        len_simulation_numbers = len(step.simulation_numbers)
+        if len_simulation_numbers > 0:
+            simulation_number = step.simulation_numbers
+            if 'LEDET' in step.software:
+                flag_yaml = True  # Hard-coded for the moment
+                flag_json = False  # Hard-coded for the moment
+                self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
+            if 'PyBBQ' in step.software:
+                self.setup_sim_PyBBQ(simulation_name=step.simulation_name, sim_number=simulation_number)
+            if 'PSPICE' in step.software:
+                self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
 
     def setup_sim_LEDET(self, simulation_name, sim_number, flag_yaml=True, flag_json=False):
         '''
