@@ -7,7 +7,7 @@ from steam_sdk.builders.BuilderPyBBQ import BuilderPyBBQ
 from steam_sdk.data.DataModelConductor import DataModelConductor
 from steam_sdk.data.DataModelMagnet import *
 from steam_sdk.data.DataModelCircuit import DataModelCircuit
-from steam_sdk.data.DataRoxieParser import APIdata
+from steam_sdk.data.DataRoxieParser import RoxieData
 from steam_sdk.builders.BuilderLEDET import BuilderLEDET
 from steam_sdk.builders.BuilderSIGMA import BuilderSIGMA
 from steam_sdk.builders.BuilderProteCCT import BuilderProteCCT
@@ -70,7 +70,7 @@ class BuilderModel:
         if case_model == 'magnet':
             # Initialize
             self.model_data: DataModelMagnet = DataModelMagnet()
-            self.roxie_data: APIdata = APIdata()
+            self.roxie_data: RoxieData = RoxieData()
             self.path_magnet = None
             self.path_data = None
             self.path_cadata = None
