@@ -119,13 +119,15 @@ class BuilderPyBBQ:
 
         RRR = self.model_data.Conductors[0].strand.RRR
         if not self.model_data.Conductors[0].cable.f_inner_voids:
-            self.model_data.Conductors[0].cable.f_inner_voids = 0
+            self.model_data.Conductors[0].cable.f_inner_voids = 0.0
         if not self.model_data.Conductors[0].cable.f_outer_voids:
-            self.model_data.Conductors[0].cable.f_outer_voids = 0
+            self.model_data.Conductors[0].cable.f_outer_voids = 0.0
         non_void = 1 - self.model_data.Conductors[0].cable.f_inner_voids - self.model_data.Conductors[0].cable.f_outer_voids
         CuSC = self.model_data.Conductors[0].strand.Cu_noCu_in_strand
         sim_name = self.model_data.GeneralParameters.conductor_name
 
+        wetted_p = (1-non_void) if strands > 1 else 0.0
+
         # Set calculated variables
         self.setAttribute(self.data_PyBBQ, 'shape',    shape)
         self.setAttribute(self.data_PyBBQ, 'width',    width)
@@ -137,3 +139,4 @@ class BuilderPyBBQ:
         self.setAttribute(self.data_PyBBQ, 'non_void', non_void)
         self.setAttribute(self.data_PyBBQ, 'CuSC',     CuSC)
         self.setAttribute(self.data_PyBBQ, 'sim_name', str(sim_name))
+        self.setAttribute(self.data_PyBBQ, 'wetted_p', wetted_p)
