@@ -59,6 +59,39 @@ def mirrorPointAboutLine(point, line):
     return [xMirrored, yMirrored]
 
 
+def intersectTwoLines(line1: list, line2: list, verbose: bool = False) -> list:
+    """
+    **Find coordinates of the intersection point between two lines**
+
+    Function returns a list:
+    - 1st element:  x
+    - 2nd element:  y
+
+    :param line1: 3-element list defining the A, B, and C coefficients of the line, as in: A*x + B*y + C = 0
+    :type line1: list
+    :param line2: 3-element list defining the A, B, and C coefficients of the line, as in: A*x + B*y + C = 0
+    :type line2: list
+    :param verbose: flag that determines whether the output are printed
+    :type verbose: bool
+    :return: list
+    """
+    a = - line1[0] / line1[1]
+    c = - line1[2] / line1[1]
+    b = - line2[0] / line2[1]
+    d = - line2[2] / line2[1]
+    q = (d - c) / (a - b)
+
+    if verbose:
+        print('A1 = {}'.format(line1[0]))
+        print('B1 = {}'.format(line1[1]))
+        print('C1 = {}'.format(line1[2]))
+        print('A2 = {}'.format(line2[0]))
+        print('B2 = {}'.format(line2[1]))
+        print('C2 = {}'.format(line2[2]))
+
+    return [q, a * q + c]
+
+
 def intersectLineCircle(line: list, circle: list, verbose: bool = False) -> list:
     """
     **Find coordinates of the zero, one, or two points where a line intersects a circle**
