@@ -148,11 +148,14 @@ class PhysicsPyBBQ(BaseModel):
     aKap: float = None
     BBackground: float = None
     BPerI: float = None
+    Heating_nodes: List[int] = None
     IDesign: float = None
+    Jc_4K_5T_NbTi: float = None
     jointLength: float = None
     jointResistancePerMeter: float = None
     muTInit: float = None
     nKap: float = None
+    Power: float = None
     QKapLimit: float = None
     Rjoint: float = None
     symmetryFactor: float = None
@@ -164,7 +167,6 @@ class PhysicsPyBBQ(BaseModel):
     VThreshold: float = None
     withCoolingToBath: bool = None
     withCoolingInternal: bool = None
-    Jc_4K_5T_NbTi: float = None
 
 
 class QuenchInitializationPyBBQ(BaseModel):
