@@ -783,7 +783,7 @@ def InterpolateResistance(current_level: float, path_resources: str, n_apertures
 
     ## Read the resistance values from a given file
     Intp_file = path_resources
-    Intp_data = pd.read_csv(Intp_file)
+    Intp_data = pd.read_csv(Intp_file, low_memory=False)
     col_t = []
     col_r1 = []
     col_r2 = []
