@@ -95,13 +95,13 @@ class RoxieList:
                 self.y_insulated.append([insulated.iL.y, insulated.oL.y, insulated.oR.y, insulated.iR.y])
                 self.x_bare.append([bare.iL.x, bare.oL.x, bare.oR.x, bare.iR.x])
                 self.y_bare.append([bare.iL.y, bare.oL.y, bare.oR.y, bare.iR.y])
-                self.i_conductor.append(winding.cable_current * block.current_sign)
+                self.i_conductor.append(block.current_sign)
 
                 for strand_gr_nr, strand_gr in halfTurn.strand_groups.items():
                     for strand_nr, strand in strand_gr.strand_positions.items():
                         self.x_strand.append(strand.x)
                         self.y_strand.append(strand.y)
-                        self.i_strand.append(winding.strand_current * block.current_sign)
+                        self.i_strand.append(block.current_sign)
                         self.strand_to_halfTurn.append(self.idx_half_turn)
 
 
@@ -110,9 +110,9 @@ class ParserRoxie:
         Class for the roxie parser
     """
 
-    data: pd.APIdata = pd.APIdata()
-    roxieData: pd.RoxieData = pd.RoxieData()
-    rawData: pd.RoxieData = pd.RoxieData()
+    data: pd.RoxieData = pd.RoxieData()
+    roxieData: pd.RoxieRawData = pd.RoxieRawData()
+    rawData: pd.RoxieRawData = pd.RoxieRawData()
 
     dir_iron: Path = None
     dir_data: Path = None
@@ -123,8 +123,9 @@ class ParserRoxie:
     block: pd.Block = pd.Block()
     group: pd.Group = pd.Group()
     trans: pd.Trans = pd.Trans()
-    condName: str = None
-    cond_parameter: pd.CondPar = pd.CondPar()
+    cond_name: str = None
+    conductor: pd.Cadata = pd.Cadata()
+    cond_parameters: pd.CondPar = pd.CondPar()
     layer_radius = []
 
     def getIronYokeDataFromIronFile(self, iron_content: str = None, verbose: bool = False):
@@ -1019,15 +1020,15 @@ class ParserRoxie:
 
             return: data
         """
-        data = self.data.conductor
+        data = self.conductor
 
         if cadata:
             self.rawData.cadata = cadata
 
         # Import selected conductor data from cadata dictionary
-        if self.condName not in data.conductor:
-            data.conductor[self.condName] = self.rawData.cadata.conductor[self.condName]
-            cond = data.conductor[self.condName]
+        if self.cond_name not in data.conductor:
+            data.conductor[self.cond_name] = self.rawData.cadata.conductor[self.cond_name]
+            cond = data.conductor[self.cond_name]
             if cond.insul not in data.insul:
                 data.insul[cond.insul] = self.rawData.cadata.insul[cond.insul]
             if cond.filament not in data.filament:
@@ -1041,7 +1042,7 @@ class ParserRoxie:
             if cond.cableGeom not in data.cable:
                 data.cable[cond.cableGeom] = self.rawData.cadata.cable[cond.cableGeom]
         else:  # Select conductor by name
-            cond = data.conductor[self.condName]
+            cond = data.conductor[self.cond_name]
 
         # Parameters defining Insulation
         cond.parameters.wInsulNarrow = data.insul[cond.insul].radial * 1e-3
@@ -1082,8 +1083,8 @@ class ParserRoxie:
             cond.parameters.noOfLayers = 2
 
         cond.parameters.lTpStrand = data.cable[cond.cableGeom].transp * 1e-3
-        cond.parameters.wCore = 0.
-        cond.parameters.hCore = 0.
+        # cond.parameters.wCore = 0.
+        # cond.parameters.hCore = 0.
         if cond.parameters.lTpStrand != 0:
             cond.parameters.thetaTpStrand = math.atan2((cond.parameters.wBare - cond.parameters.dstrand),
                                                        (cond.parameters.lTpStrand / 2))
@@ -1091,15 +1092,15 @@ class ParserRoxie:
             cond.parameters.thetaTpStrand = 0.
 
         cond.parameters.degradation = data.cable[cond.cableGeom].degrd / 100
-        cond.parameters.C1 = 0.
-        cond.parameters.C2 = 0.
-        cond.parameters.fracHe = 0.
-        cond.parameters.fracFillInnerVoids = 1.
-        cond.parameters.fracFillOuterVoids = 1.
+        # cond.parameters.C1 = 0.
+        # cond.parameters.C2 = 0.
+        # cond.parameters.fracHe = 0.
+        # cond.parameters.fracFillInnerVoids = 1.
+        # cond.parameters.fracFillOuterVoids = 1.
 
         cond.parameters.Top = cond.T_0
 
-        self.cond_parameter = cond.parameters
+        self.cond_parameters = cond.parameters
 
         return data
 
@@ -1120,8 +1121,8 @@ class ParserRoxie:
         """
         if block:
             self.block = block
-            self.data = pd.APIdata()
-            self.cond_parameter = conductor
+            self.data = pd.RoxieData()
+            self.cond_parameters = conductor
             self.no = 1
 
         x0 = 0
@@ -1143,14 +1144,14 @@ class ParserRoxie:
         y0Roll = self.block.roll2.coor.y / 1e3  # in [m]
         alphaRoll = self.block.roll2.alph / 180 * math.pi  # in [rad]
 
-        wBare = self.cond_parameter.wBare
-        hInBare = self.cond_parameter.hInBare
-        hOutBare = self.cond_parameter.hOutBare
+        wBare = self.cond_parameters.wBare
+        hInBare = self.cond_parameters.hInBare
+        hOutBare = self.cond_parameters.hOutBare
         # hBare = (hInBare + hOutBare) / 2
-        wInsulNarrow = self.cond_parameter.wInsulNarrow
-        wInsulWide = self.cond_parameter.wInsulWide
-        nColumns = self.cond_parameter.noOfStrandsPerLayer
-        nLayers = self.cond_parameter.noOfLayers
+        wInsulNarrow = self.cond_parameters.wInsulNarrow
+        wInsulWide = self.cond_parameters.wInsulWide
+        nColumns = self.cond_parameters.noOfStrandsPerLayer
+        nLayers = self.cond_parameters.noOfLayers
 
         # Define the coefficients of the circle on which the x2 points (bottom-left) of each conductor rest
         # R, x0, and y0 coefficients of the circle, as in: (x-x0)**2 + (y-y0)**2 = R**2
@@ -1176,9 +1177,10 @@ class ParserRoxie:
         layer = pole.layers[self.block.layer]
         if self.block.winding not in layer.windings:
             layer.windings[self.block.winding] = \
-                pd.WindingData(nco=self.block.nco, cable_current=float(sigDig(abs(self.block.current))),
-                               conductor_name=self.block.condname,
-                               strand_current=float(sigDig(abs(self.block.current / self.cond_parameter.noOfStrands))))
+                pd.WindingData(conductors_number=self.block.nco, conductor_name=self.block.condname)
+                # pd.WindingData(nco=self.block.nco, cable_current=float(sigDig(abs(self.block.current))),
+                #                conductor_name=self.block.condname,
+                #                strand_current=float(sigDig(abs(self.block.current / self.cond_parameter.noOfStrands))))
         winding = layer.windings[self.block.winding]
 
         # Initialize object for this block
@@ -1519,12 +1521,13 @@ class ParserRoxie:
                          block=self.no))
 
             # Get desired conductor data
-            self.condName = self.block.condname
+            self.cond_name = self.block.condname
             self.getConductorFromCableDatabase(cadata=cadata)
 
             # Calculate x/y positions of the conductor corners and strands
             if verbose:
                 print('Block {} is of type {} --> {}.'.format(self.no, self.block.type, blockTypes[self.block.type]))
+
             self.findConductorPositions(verbose=verbose)
 
         # if verbose:
@@ -1607,9 +1610,9 @@ class ParserRoxie:
             :return: list
         """
         # Re-initialize dictionaries
-        self.data: pd.APIdata = pd.APIdata()
-        self.roxieData: pd.RoxieData = pd.RoxieData()
-        self.rawData: pd.RoxieData = pd.RoxieData()
+        self.data: pd.RoxieData = pd.RoxieData()
+        self.roxieData: pd.RoxieRawData = pd.RoxieRawData()
+        self.rawData: pd.RoxieRawData = pd.RoxieRawData()
 
         # Acquire iron yoke data from the .iron Roxie file
         if dir_iron:
