@@ -135,6 +135,7 @@ class Viewer:
 
         # Unpack inputs
         verbose = self.verbose
+        dict_configs = self.dict_configs
         list_events = self.list_events
         dict_events = self.dict_events
 
@@ -163,6 +164,19 @@ class Viewer:
                 print(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: WARNING. flag_convert_meas_csv=1, but output folder for converted files (path_output_measurement_files) not defined.')
                 continue  # Measurement file not defined: go to the next event
 
+            # Compile a list of the signal groups that are requested in the configuration file (only the data of those groups will be converted)
+            requested_groups = []
+            configuration_name = dict_events['Configuration'][t-1]
+            configuration      = dict_configs[configuration_name]
+
+            for signal in configuration.SignalList:
+                meas_signals_to_add = signal.meas_signals_to_add_x + signal.meas_signals_to_add_y
+                for s, _ in enumerate(meas_signals_to_add):
+                    group_name = meas_signals_to_add[s].split('.')[0]  # group where the current signal is located
+                    requested_groups.append(group_name)
+            requested_groups = unique(requested_groups)  # Delete elements that appear twice in these two lists
+            if verbose: print(f'Row {t}: Requested groups: {requested_groups}.')
+
             # Check that the measurement file exists
             full_path_meas_file     = Path(os.path.join(measurement_folder, campaign, meas + '.tdms')).resolve()
             path_meas_csv_folder    = Path(os.path.join(path_output_measurement_files, campaign)).resolve()  # each subfolder in this folder represents a test campaign
@@ -170,18 +184,13 @@ class Viewer:
             if not os.path.isfile(full_path_meas_file):
                 raise Exception(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Measurement file {full_path_meas_file} not found.')
 
+            # Convert the requested groups of the .tdms file to separate .csv files
             if flag_convert_meas_csv == 1:
-                if os.path.isfile(full_path_meas_csv_file):
-                    if verbose: print(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Converted measurement file {full_path_meas_csv_file} already exist, and it will not be overwritten. (in order to overwrite, you can set flag_convert_meas_csv=2).')
-                    pass  # do nothing
-                else:
-                    if verbose: print(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Measurement file {full_path_meas_file} converted to {full_path_meas_csv_file}.')
-                    tdms_file = ParserTdms(full_path_meas_file)
-                    tdms_file.convertTdmsToCsv(full_path_meas_csv_file, selected_groups= [])  # Convert all groups of the .tdms file to separate .csv files
-            elif flag_convert_meas_csv == 2:
-                if verbose: print(f'Row {t}: flag_convert_meas_csv={flag_convert_meas_csv}: Measurement file {full_path_meas_file} converted to {full_path_meas_csv_file} (if already present, it was overwritten).')
                 tdms_file = ParserTdms(full_path_meas_file)
-                tdms_file.convertTdmsToCsv(full_path_meas_csv_file, selected_groups= [])  # Convert all groups of the .tdms file to separate .csv files
+                tdms_file.convertTdmsToCsv(full_path_meas_csv_file, selected_groups= requested_groups, flag_overwrite=False)  # do not overwrite existing files
+            elif flag_convert_meas_csv == 2:
+                tdms_file = ParserTdms(full_path_meas_file)
+                tdms_file.convertTdmsToCsv(full_path_meas_csv_file, selected_groups= requested_groups, flag_overwrite=True)  # overwrite existing files
             else:
                 raise Exception(f'Entry flag_convert_meas_csv={flag_convert_meas_csv} in the event file {self.file_name_transients} is not supported.')
 
@@ -193,10 +202,11 @@ class Viewer:
         '''
         # Unpack inputs
         verbose = self.verbose
-        dict_events = self.dict_events
         dict_configs = self.dict_configs
+        dict_events = self.dict_events
         list_events = self.list_events
 
+
         if verbose: print('### Perform analysis. ###')
 
         for t in list_events:
@@ -413,7 +423,7 @@ class Viewer:
         # If the list of signals to add is empty, return an empty pandas series
         n_signals_to_add = len(signals_to_add)
         if n_signals_to_add == 0:
-            return pd.Series([])
+            return pd.Series([], dtype=float)
 
         # If multipliers or offsets are empty lists, use default values (signals unchanged)
         if len(multipliers) == 0:
